from .letters import YIDDISH_LETTER_LOOKUP, YIDDISH_PREFIX_LOOKUP
from .letters import YIDDISH_WORD_LOOKUP


def yiddish_to_roman(s):
    if not s:
        return ""
    if " " in s:
        words = s.split(" ")
        return " ".join(yiddish_to_roman(w) for w in words)
    if s in YIDDISH_WORD_LOOKUP:
        return YIDDISH_WORD_LOOKUP[s]
    return _yiddish_to_roman_simple_word(s)


def _yiddish_to_roman_simple_word(s):
    for y in YIDDISH_PREFIX_LOOKUP:
        if s.startswith(y):
            ss = s[len(y):]
            return YIDDISH_PREFIX_LOOKUP[y] + yiddish_to_roman(ss)
    r = []
    b = ""
    for c in s:
        if c in YIDDISH_LETTER_LOOKUP:
            r.append(YIDDISH_LETTER_LOOKUP[c])
        elif b + c in YIDDISH_LETTER_LOOKUP:
            r.append(YIDDISH_LETTER_LOOKUP[b + c])
        else:
            b = c
    return "".join(r)



from .letters import ROMAN_FINAL_LOOKUP, ROMAN_LOOKUP


def roman_to_yiddish(s):
    if not s:
        return ""
    if " " in s:
        words = s.split(" ")
        return " ".join(roman_to_yiddish(w) for w in words)
    if len(s) == 1 and s in ROMAN_FINAL_LOOKUP:
        return ROMAN_FINAL_LOOKUP[s]
    prefixes = [ x for x in ROMAN_LOOKUP if s.startswith(x) ]
    if prefixes:
        prefixes.sort(key=len)
        x = prefixes[-1]
        return ROMAN_LOOKUP[x] + roman_to_yiddish(s[len(x):])
    raise ValueError("Couldn't find the first Yiddish character of %s" % (s, ))



YIDDISH_LETTERS = [
    ("אֵ", "a"),
    ("אׇ", "o"),
    ("ב", "b"),
    ("ג", "g"),
    ("ד", "d"),
    ("ה", "h"),
    ("ו", "u"),
    ("ז", "z"),
    ("ט", "t"),
    ("י", "i"),
    ("כ", "kh"),
    ("ל", "l"),
    ("מ", "m"),
    ("נ", "n"),
    ("ס", "s"),
    ("ע", "e"),
    ("ף", "f"),
    ("ר", "r"),
    ("ש", "sh"),
    ("ײ", "ey"),
]

YIDDISH_FINAL_LETTERS = [
    ("ן", "n"),
]

YIDDISH_DOUBLE_LETTERS = [
    ("װ", "v"),
    ("ױ", "oy"),
]

YIDDISH_SYMBOLS = [
    ("־", "-"),
]

COMPOSITE_SOUNDS = [
    ("ייִ", "yi"),
    ("ח", "kha"),
    ("בֿ", "ve"),
    ("וּו", "uu"),
]

YIDDISH_WORDS = [
    ("אויף", "af"),
    ("ייִדיש", "yiddish"),
]

YIDDISH_LETTER_LOOKUP = {
    x[0]: x[1] for x in
    YIDDISH_LETTERS +
    YIDDISH_DOUBLE_LETTERS +
    YIDDISH_SYMBOLS +
    YIDDISH_FINAL_LETTERS
}

YIDDISH_PREFIX_LOOKUP = {
    x[0]: x[1] for x in COMPOSITE_SOUNDS
}

YIDDISH_WORD_LOOKUP = {
    x[0]: x[1] for x in YIDDISH_WORDS
}

ROMAN_LETTER_LOOKUP = {
    x[1]: x[0] for x in YIDDISH_LETTERS
}

ROMAN_SYMBOL_LOOKUP = {
    x[1]: x[0] for x in YIDDISH_SYMBOLS
}

ROMAN_DOUBLE_LETTER_LOOKUP = {
    x[1]: x[0] for x in YIDDISH_DOUBLE_LETTERS
}

ROMAN_FINAL_LETTER_LOOKUP = {
    x[1]: x[0] for x in YIDDISH_FINAL_LETTERS
}

ROMAN_ALIAS_LOOKUP = {
    "dd": "d"
}

ROMAN_COMPOSITE_LOOKUP = {
    x[1]: x[0] for x in COMPOSITE_SOUNDS
}

ROMAN_LOOKUP = ROMAN_LETTER_LOOKUP.copy()
ROMAN_LOOKUP.update(ROMAN_DOUBLE_LETTER_LOOKUP)
ROMAN_LOOKUP.update(ROMAN_SYMBOL_LOOKUP)
ROMAN_LOOKUP.update(ROMAN_COMPOSITE_LOOKUP)
ROMAN_LOOKUP.update({ x: ROMAN_LETTER_LOOKUP[ROMAN_ALIAS_LOOKUP[x]] for x in ROMAN_ALIAS_LOOKUP })

ROMAN_FINAL_LOOKUP = ROMAN_LETTER_LOOKUP.copy()
ROMAN_FINAL_LOOKUP.update(ROMAN_FINAL_LETTER_LOOKUP)



from setuptools import setup

setup(
    name='iberzetsn',
    version='0.1.1',
    description='A library for Yiddish transliteration',
    url='https://github.com/jwg4/iberzetsn',
    author='Jack Grahl',
    author_email='jack.grahl@gmail.com',
    license='MIT',
    packages=["iberzetsn"],
    test_suite="tests"
)
